@@ -3,7 +3,7 @@
 # @Time: 2021/6/27 20:47
 # @Author: CACode
 # 版本有三种状态 正式版从1.0.0往后逐个加 1,对应版本的补丁为'a+补丁次数'
-__version__ = '1.0.7'
+__version__ = '1.0.8'
 __description__ = "Aestate framework for Python,You can see:https://gitee.com/aecode/aestate"
 __author__ = "CACode"
 __author_email__ = "cacode@163.com"
@@ -55,42 +55,42 @@ class Commands:
                 "显示aestate的版本号",
                 "aestate -v"
             ),
-            "-create": (
-                self.create,
-                "将文件内存在pojo对象的类生成到数据库中称为数据库的表"
-                "数据库格式化类型参考默认的 [mysql] 格式",
-                'aestate -create [文件名] [数据库类型 (可选)]'
-            ),
-            "-m": (
-                self.make,
-                "将数据库中的表同步生成到当前目录下的 [model.py]，并默认命名为 [数据库命_表名]",
-                'aestate -m [--n [生成的文件名 (可选) ]] [--nn [生成的类名 (可选)]]'
-            ),
-            "-enc": (
-                self.enc,
-                "加密模型",
-                'aestate -enc [密码]'
-            ),
-            "-dec": (
-                self.dec,
-                "解密模型",
-                'aestate -dec [被加密后的文件] [密码]'
-            ),
-            "-check": (
-                self.check,
-                "检查模型与数据库中的表结构是否一直",
-                'aestate -check [文件名] [数据库名]'
-            ),
-            "-h": (
-                self.help,
-                "帮助文档",
-                'aestate -h'
-            ),
-            "-g": (
-                self.generate,
-                "在当前目录下生成一个",
-                'aestate -gc 项目名'
-            )
+            # "-create": (
+            #     self.create,
+            #     "将文件内存在pojo对象的类生成到数据库中称为数据库的表"
+            #     "数据库格式化类型参考默认的 [mysql] 格式",
+            #     'aestate -create [文件名] [数据库类型 (可选)]'
+            # ),
+            # "-m": (
+            #     self.make,
+            #     "将数据库中的表同步生成到当前目录下的 [model.py]，并默认命名为 [数据库命_表名]",
+            #     'aestate -m [--n [生成的文件名 (可选) ]] [--nn [生成的类名 (可选)]]'
+            # ),
+            # "-enc": (
+            #     self.enc,
+            #     "加密模型",
+            #     'aestate -enc [密码]'
+            # ),
+            # "-dec": (
+            #     self.dec,
+            #     "解密模型",
+            #     'aestate -dec [被加密后的文件] [密码]'
+            # ),
+            # "-check": (
+            #     self.check,
+            #     "检查模型与数据库中的表结构是否一直",
+            #     'aestate -check [文件名] [数据库名]'
+            # ),
+            # "-h": (
+            #     self.help,
+            #     "帮助文档",
+            #     'aestate -h'
+            # ),
+            # "-g": (
+            #     self.generate,
+            #     "在当前目录下生成一个",
+            #     'aestate -gc 项目名'
+            # )
         }
 
     def generate(self):
